aboutsummaryrefslogtreecommitdiff
path: root/src/rpc/util.cpp
diff options
context:
space:
mode:
authorAndrew Chow <achow101-github@achow101.com>2019-06-06 16:31:31 +0200
committerAndrew Chow <achow101-github@achow101.com>2019-07-09 15:28:41 -0400
commitc7797ec65544bd23a2e571b2892e1bf512f2a485 (patch)
treed473c0d165c5fda861811ee0403f8a6ca2b0c846 /src/rpc/util.cpp
parent1b699a5083b435c2b79f3951f94ac9f967d24f6c (diff)
downloadbitcoin-c7797ec65544bd23a2e571b2892e1bf512f2a485.tar.xz
Remove CKeyStore and squash into CBasicKeyStore
Diffstat (limited to 'src/rpc/util.cpp')
-rw-r--r--src/rpc/util.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/rpc/util.cpp b/src/rpc/util.cpp
index 67ccb225b5..65a1b39dd0 100644
--- a/src/rpc/util.cpp
+++ b/src/rpc/util.cpp
@@ -131,8 +131,8 @@ CPubKey HexToPubKey(const std::string& hex_in)
return vchPubKey;
}
-// Retrieves a public key for an address from the given CKeyStore
-CPubKey AddrToPubKey(CKeyStore* const keystore, const std::string& addr_in)
+// Retrieves a public key for an address from the given CBasicKeyStore
+CPubKey AddrToPubKey(CBasicKeyStore* const keystore, const std::string& addr_in)
{
CTxDestination dest = DecodeDestination(addr_in);
if (!IsValidDestination(dest)) {
@@ -153,7 +153,7 @@ CPubKey AddrToPubKey(CKeyStore* const keystore, const std::string& addr_in)
}
// Creates a multisig address from a given list of public keys, number of signatures required, and the address type
-CTxDestination AddAndGetMultisigDestination(const int required, const std::vector<CPubKey>& pubkeys, OutputType type, CKeyStore& keystore, CScript& script_out)
+CTxDestination AddAndGetMultisigDestination(const int required, const std::vector<CPubKey>& pubkeys, OutputType type, CBasicKeyStore& keystore, CScript& script_out)
{
// Gather public keys
if (required < 1) {